import { __decorate } from 'tslib';
import { ɵɵdefineInjectable, Injectable, ɵɵinject, NgModule } from '@angular/core';
import { Storage, IonicStorageModule } from '@ionic/storage';

let IonicStorageService = class IonicStorageService {
    constructor() { }
};
IonicStorageService.ɵprov = ɵɵdefineInjectable({ factory: function IonicStorageService_Factory() { return new IonicStorageService(); }, token: IonicStorageService, providedIn: "root" });
IonicStorageService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], IonicStorageService);

let IonicTokenService = class IonicTokenService {
    constructor(storage) {
        this.storage = storage;
        this.tokenName = 'api_refresh_token';
    }
    getRefreshToken() {
        return new Promise((resolve, reject) => {
            this.storage.get(this.tokenName).then(value => {
                resolve(value);
            }).catch(() => {
                reject();
            });
        });
    }
    deleteRefreshToken() {
        return new Promise((resolve, reject) => {
            this.storage.remove(this.tokenName).then(() => {
                resolve(null);
            }).catch(() => {
                reject();
            });
        });
    }
    setRefreshToken(token) {
        return new Promise((resolve, reject) => {
            this.storage.set(this.tokenName, token).then(() => {
                resolve(null);
            }).catch(() => {
                reject();
            });
        });
    }
};
IonicTokenService.ctorParameters = () => [
    { type: Storage }
];
IonicTokenService.ɵprov = ɵɵdefineInjectable({ factory: function IonicTokenService_Factory() { return new IonicTokenService(ɵɵinject(Storage)); }, token: IonicTokenService, providedIn: "root" });
IonicTokenService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], IonicTokenService);

let IonicCacheService = class IonicCacheService {
    constructor(storage) {
        this.storage = storage;
        this.prefix = 'io-cache-';
    }
    /**
     * Add Data to Cache
     * @param key
     *  Cache Key
     * @param data
     *  Data to cache
     * @param expire
     *  Expiration in seconds. Optional, default: 900 (i.e. 15 minutes)
     */
    set(key, data, expire) {
        return new Promise((resolve, reject) => {
            if (expire === undefined) {
                expire = 900;
            }
            const ex = new Date();
            ex.setSeconds(ex.getSeconds() + expire);
            const cache = {
                key: key,
                data: data,
                expire: ex,
            };
            this.storage.set(this.prefix + key, cache).then(() => {
                resolve(null);
            }).catch((error) => {
                reject(error);
            });
        });
    }
    /**
     * Get data from Cache
     * @param key
     *  Cache Key
     *
     * The request is rejected, if no data exists or data is expired.
     */
    get(key) {
        return new Promise((resolve, reject) => {
            this.storage.get(this.prefix + key).then((cache) => {
                const now = new Date();
                const expire = new Date(cache.expire);
                if (expire > now) {
                    resolve(cache.data);
                }
                else {
                    this.storage.remove(this.prefix + key);
                    reject();
                }
            }).catch((error) => {
                reject();
            });
        });
    }
};
IonicCacheService.ctorParameters = () => [
    { type: Storage }
];
IonicCacheService.ɵprov = ɵɵdefineInjectable({ factory: function IonicCacheService_Factory() { return new IonicCacheService(ɵɵinject(Storage)); }, token: IonicCacheService, providedIn: "root" });
IonicCacheService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], IonicCacheService);

let IonicDataStorageModule = class IonicDataStorageModule {
};
IonicDataStorageModule = __decorate([
    NgModule({
        imports: [
            IonicStorageModule.forRoot(),
        ],
    })
], IonicDataStorageModule);

/*
 * Public API Surface of ionic-storage
 */

/**
 * Generated bundle index. Do not edit.
 */

export { IonicCacheService, IonicDataStorageModule, IonicStorageService, IonicTokenService };
//# sourceMappingURL=attus-ionic-storage.js.map
